=====================
Styler REST Framework
=====================


.. image:: https://img.shields.io/pypi/v/styler_rest_framework.svg
        :target: https://pypi.python.org/pypi/styler_rest_framework

.. image:: https://github.com/STYLER-Inc/styler-rest-framework/workflows/Python%20package/badge.svg


Standards used in REST services



Installation
------------

* TODO


Usage
-----

* TODO
